#include <sys/cdefs.h>

#include "opt_config.h"

/*
 * Add either (or both) of
 *
 *	options INCLUDE_CONFIG_FILE
 *	options INCLUDE_JUST_CONFIG
 *
 * to your kernel config file to embed it in the resulting
 * kernel.  The latter option does not include files that are
 * included (recursively) by your config file.  The embedded
 * data be extracted by using the command:
 *
 *	strings netbsd | sed -n 's/^_CFG_//p' | unvis
 */

#ifdef CONFIG_FILE
#if defined(INCLUDE_CONFIG_FILE) || defined(INCLUDE_JUST_CONFIG)

static const char config[] __used =

#ifdef INCLUDE_CONFIG_FILE

"_CFG_### START CONFIG FILE \"GENERIC.SKI\"\n"

#endif /* INCLUDE_CONFIG_FILE */

"_CFG_# $NetBSD: GENERIC.SKI,v 1.15 2018/08/14 06:37:59 maxv Exp $\n"
"_CFG_#\n"
"_CFG_# GENERIC machine description file\n"
"_CFG_#\n"
"_CFG_# This machine description file is used to generate the default NetBSD\n"
"_CFG_# kernel.  The generic kernel does not include all options, subsystems\n"
"_CFG_# and device drivers, but should be useful for most applications.\n"
"_CFG_#\n"
"_CFG_# The machine description file can be customised for your specific\n"
"_CFG_# machine to reduce the kernel size and improve its performance.\n"
"_CFG_#\n"
"_CFG_# For further information on compiling NetBSD kernels, see the config(8)\n"
"_CFG_# man page.\n"
"_CFG_#\n"
"_CFG_# For further information on hardware support for this architecture, see\n"
"_CFG_# the intro(4) man page.  For further information about kernel options\n"
"_CFG_# for this architecture, see the options(4) man page.  For an explanation\n"
"_CFG_# of each device driver in this file see the section 4 man page for the\n"
"_CFG_# device.\n"
"_CFG_\n"
"_CFG_include \\011\"arch/ia64/conf/std.ia64\"\n"
"_CFG_\n"
"_CFG_options \\011INCLUDE_CONFIG_FILE\\011# embed config file in kernel binary\n"
"_CFG_\n"
"_CFG_#ident \\011\\011\"GENERIC-$Revision: 1.15 $\"\n"
"_CFG_\n"
"_CFG_maxusers\\01132\\011\\011# estimated number of users\n"
"_CFG_\n"
"_CFG_# CPU support.  At least one is REQUIRED.\n"
"_CFG_#options\\011IA64_CPU\n"
"_CFG_\n"
"_CFG_# CPU-related options.\n"
"_CFG_\n"
"_CFG_# Standard system options\n"
"_CFG_options \\011INSECURE\\011# disable kernel security levels - X needs this\n"
"_CFG_options \\011NTP\\011\\011# NTP phase/frequency locked loop\n"
"_CFG_\n"
"_CFG_options \\011KTRACE\\011\\011# system call tracing via ktrace(1)\n"
"_CFG_\n"
"_CFG_# Note: SysV IPC parameters can be changed dynamically; see sysctl(8).\n"
"_CFG_options \\011SYSVMSG\\011\\011# System V-like message queues\n"
"_CFG_options \\011SYSVSEM\\011\\011# System V-like semaphores\n"
"_CFG_options \\011SYSVSHM\\011\\011# System V-like memory sharing\n"
"_CFG_\n"
"_CFG_#options \\011MODULAR\\011\\011# new style module(7) framework\n"
"_CFG_#options \\011MODULAR_DEFAULT_AUTOLOAD\n"
"_CFG_\n"
"_CFG_options \\011USERCONF\\011# userconf(4) support\n"
"_CFG_\n"
"_CFG_# Diagnostic/debugging support options\n"
"_CFG_options \\011DIAGNOSTIC\\011# expensive kernel consistency checks\n"
"_CFG_options \\011DEBUG\\011\\011# expensive debugging checks/support\n"
"_CFG_#options \\011LOCKDEBUG\\011# expensive locking checks/support\n"
"_CFG_options \\011DDB\\011\\011# in-kernel debugger\n"
"_CFG_options \\011DDB_ONPANIC=1\\011# see also sysctl(7): `ddb.onpanic'\n"
"_CFG_#options \\011DDB_HISTORY_SIZE=512\\011# enable history editing in DDB\n"
"_CFG_#options \\011KGDB\\011\\011# remote debugger\n"
"_CFG_#options \\011KGDB_DEVNAME=\"\\134\"com\\134\"\",KGDB_DEVADDR=0x3f8,KGDB_DEVRATE=9600\n"
"_CFG_makeoptions\\011DEBUG=\"-g\"\\011# compile full symbol table\n"
"_CFG_#makeoptions\\011COPY_SYMTAB=1\n"
"_CFG_\n"
"_CFG_#options UVMHIST\n"
"_CFG_#options UVMHIST_PRINT\n"
"_CFG_\n"
"_CFG_# File systems\n"
"_CFG_file-system\\011FFS\\011\\011# UFS\n"
"_CFG_file-system\\011NFS\\011\\011# Network File System client\n"
"_CFG_file-system \\011MFS\\011\\011# memory file system\n"
"_CFG_file-system\\011LFS\\011\\011# log-structured file system\n"
"_CFG_#file-system\\011NTFS\\011\\011# Windows/NT file system (experimental)\n"
"_CFG_file-system\\011CD9660\\011\\011# ISO 9660 + Rock Ridge file system\n"
"_CFG_#file-system\\011MSDOSFS\\011\\011# MS-DOS file system\n"
"_CFG_#file-system\\011FDESC\\011\\011# /dev/fd\n"
"_CFG_file-system\\011KERNFS\\011\\011# /kern\n"
"_CFG_file-system\\011NULLFS\\011\\011# loopback file system\n"
"_CFG_#file-system\\011OVERLAY\\011\\011# overlay file system\n"
"_CFG_#file-system\\011PROCFS\\011\\011# /proc\n"
"_CFG_\n"
"_CFG_#options \\011GATEWAY\\011\\011# packet forwarding\n"
"_CFG_options \\011INET\\011\\011# IP + ICMP + TCP + UDP\n"
"_CFG_#options \\011INET6\\011\\011# IPv6\n"
"_CFG_#options \\011IPSEC\\011\\011# IP security\n"
"_CFG_\n"
"_CFG_#options \\011NFS_BOOT_DHCP,NFS_BOOT_BOOTPARAM\n"
"_CFG_\n"
"_CFG_# Kernel root file system and dump configuration.\n"
"_CFG_config\\011\\011netbsd\\011root on ? type ?\n"
"_CFG_#config\\011\\011netbsd\\011root on md0a type ffs\n"
"_CFG_#config\\011\\011netbsd\\011root on sd0a type ffs\n"
"_CFG_#config\\011\\011netbsd\\011root on ? type nfs\n"
"_CFG_\n"
"_CFG_#\n"
"_CFG_# Device configuration\n"
"_CFG_#\n"
"_CFG_\n"
"_CFG_mainbus0 at root\n"
"_CFG_\n"
"_CFG_cpu* at mainbus?\n"
"_CFG_\n"
"_CFG_#options \\011ACPI_SCANPCI\\011# find PCI roots using ACPI\n"
"_CFG_\n"
"_CFG_acpi0 at mainbus?\n"
"_CFG_\n"
"_CFG_\n"
"_CFG_# Pull in optional local configuration\n"
"_CFG_cinclude \"arch/ia64/conf/GENERIC.local\"\n"
"_CFG_\n"
"_CFG_# Console Devices\n"
"_CFG_#ssccons*\\011at mainbus0\\011\\011# Ski console interface driver\n"
"_CFG_#wsdisplay*\\011at ssccons0 console ?\n"
"_CFG_#wskbd*\\011\\011at ssccons0 console ?\n"
"_CFG_\n"
"_CFG_# Pseudo-Devices\n"
"_CFG_\n"
"_CFG_# Enable the hooks used for initializing the root memory-disk.\n"
"_CFG_pseudo-device\\011md\\011\\011\\011# memory disk device (ramdisk)\n"
"_CFG_#options \\011MEMORY_DISK_DYNAMIC\\011# loaded via kernel module(7)\n"
"_CFG_##options \\011MEMORY_DISK_HOOKS\\011# enable root ramdisk\n"
"_CFG_##options\\011\\011MEMORY_DISK_IS_ROOT\\011# force md RAM disk to be the root device\n"
"_CFG_#options    MEMORY_DISK_ROOT_SIZE=2880  # 1.44M, same as a floppy\n"
"_CFG_##options     MEMORY_DISK_ROOT_SIZE=8192  # 4Meg\n"
"_CFG_##options     MEMORY_DISK_SERVER=1        # make the ramdisk writeable\n"
"_CFG_\n"
"_CFG_#pseudo-device\\011vnd\\011\\011\\011# disk-like interface to files\n"
"_CFG_#options \\011VND_COMPRESSION\\011\\011# compressed vnd(4)\n"
"_CFG_\n"
"_CFG_pseudo-device\\011ssccons\\011\\011\\011# Ski emulator console\n"
"_CFG_#pseudo-device\\011wsmux\\011\\011\\011# mouse & keyboard multiplexor\n"
"_CFG_#pseudo-device\\011wsfont\n"
"_CFG_pseudo-device\\011ksyms\\011\\011\\011# /dev/ksyms\n"
"_CFG_\n"
"_CFG_# network pseudo-devices\n"
"_CFG_#pseudo-device\\011bpfilter\\011\\011# Berkeley packet filter\n"
"_CFG_#pseudo-device\\011carp\\011\\011\\011# Common Address Redundancy Protocol\n"
"_CFG_pseudo-device\\011loop\\011\\011\\011# network loopback\n"
"_CFG_#pseudo-device\\011ifmpls\\011\\011\\011# MPLS pseudo-interface\n"
"_CFG_#pseudo-device\\011ppp\\011\\011\\011# Point-to-Point Protocol\n"
"_CFG_#pseudo-device\\011pppoe\\011\\011\\011# PPP over Ethernet (RFC 2516)\n"
"_CFG_#options \\011PPPOE_SERVER\\011\\011# Enable PPPoE server via link0\n"
"_CFG_#pseudo-device\\011sl\\011\\011\\011# Serial Line IP\n"
"_CFG_#pseudo-device\\011strip\\011\\011\\011# Starmode Radio IP (Metricom)\n"
"_CFG_#pseudo-device\\011irframetty\\011\\011# IrDA frame line discipline\n"
"_CFG_#pseudo-device\\011tap\\011\\011\\011# virtual Ethernet\n"
"_CFG_#pseudo-device\\011tun\\011\\011\\011# network tunneling over tty\n"
"_CFG_#pseudo-device\\011gre\\011\\011\\011# generic L3 over IP tunnel\n"
"_CFG_#pseudo-device\\011gif\\011\\011\\011# IPv[46] over IPv[46] tunnel (RFC 1933)\n"
"_CFG_#pseudo-device\\011faith\\011\\011\\011# IPv[46] TCP relay translation i/f\n"
"_CFG_#pseudo-device\\011stf\\011\\011\\011# 6to4 IPv6 over IPv4 encapsulation\n"
"_CFG_#pseudo-device\\011vlan\\011\\011\\011# IEEE 802.1q encapsulation\n"
"_CFG_#pseudo-device\\011bridge\\011\\011\\011# simple inter-network bridging\n"
"_CFG_#options \\011BRIDGE_IPF\\011\\011# bridge uses IP/IPv6 pfil hooks too\n"
"_CFG_#pseudo-device\\011agr\\011\\011\\011# IEEE 802.3ad link aggregation\n"
"_CFG_#pseudo-device\\011npf\\011\\011\\011# NPF packet filter\n"
"_CFG_#pseudo-device\\011l2tp\\011\\011\\011# L2TPv3 interface\n"
"_CFG_# srt is EXPERIMENTAL\n"
"_CFG_#pseudo-device\\011srt\\011\\011\\011# source-address-based routing\n"
"_CFG_\n"
"_CFG_# miscellaneous pseudo-devices\n"
"_CFG_pseudo-device\\011pty\\011\\011\\011# pseudo-terminals\n"
#ifdef INCLUDE_CONFIG_FILE

"_CFG_### END CONFIG FILE \"GENERIC.SKI\"\n"
"_CFG_### (included from \"arch/ia64/conf/std.ia64\")\n"
"_CFG_###> # $NetBSD: std.ia64,v 1.2 2006/07/02 17:23:59 cherry Exp $\n"
"_CFG_###> #\n"
"_CFG_###> # Standard/required configuration info for NetBSD/ia64\n"
"_CFG_###> \n"
"_CFG_###> machine\\011\\011ia64\n"
"_CFG_###> include\\011\\011\"conf/std\"\\011# MI standard options\n"
"_CFG_###> \n"
"_CFG_###> options \\011EXEC_ELF64\\011# exec ELF binaries\n"
"_CFG_###> options \\011EXEC_SCRIPT\\011# exec #! scripts\n"
"_CFG_###> \n"
"_CFG_### (end include \"arch/ia64/conf/std.ia64\")\n"
"_CFG_### (included from \"conf/std\")\n"
"_CFG_###> # $NetBSD: std,v 1.23 2019/01/27 02:08:41 pgoyette Exp $\n"
"_CFG_###> #\n"
"_CFG_###> # standard MI 'options'\n"
"_CFG_###> #\n"
"_CFG_###> # this file is for options which can't be off-by-default for some reasons.\n"
"_CFG_###> # \"it's commonly used\" is NOT a good reason to enable options here.\n"
"_CFG_###> \n"
"_CFG_###> #\n"
"_CFG_###> # Always include \"kern\" attribute (module).  Other attributes don't need to\n"
"_CFG_###> # depend on \"kern\".\n"
"_CFG_###> #\n"
"_CFG_###> select\\011kern\n"
"_CFG_###> \n"
"_CFG_###> # Always include the \"vfs\" attribute (module).  Although all of the\n"
"_CFG_###> # ufs/xxx file systems depend on the vfs attribute, it is not required\n"
"_CFG_###> # that any file system actually be built-in to the kernel.  (At least\n"
"_CFG_###> # on some architectures, file system modules can be loaded at boot\n"
"_CFG_###> # time.)\n"
"_CFG_###> \n"
"_CFG_###> select vfs\n"
"_CFG_###> \n"
"_CFG_###> select\\011net\\011\\011# XXX Clean up dependency\n"
"_CFG_###> \n"
"_CFG_###> # the following options are on-by-default to keep\n"
"_CFG_###> # kernel config file compatibility.\n"
"_CFG_###> options\\011VMSWAP\\011\\011# Swap device/file support\n"
"_CFG_###> options\\011BUFQ_FCFS\\011# First-come First-serve strategy\n"
"_CFG_###> options\\011BUFQ_DISKSORT\\011# Traditional min seek sort strategy\n"
"_CFG_###> options\\011RFC2292\\011\\011# Previous version of Adv. Sockets API for IPv6 \n"
"_CFG_###> options\\011PTRACE\\011\\011# Include ptrace(2) syscall\n"
"_CFG_###> options\\011PTRACE_HOOKS\\011# Include ptrace hooks\n"
"_CFG_###> options\\011COREDUMP\\011# allow processes to coredump.\n"
"_CFG_###> options\\011AIO\\011\\011# POSIX asynchronous I/O\n"
"_CFG_###> options\\011MQUEUE\\011\\011# POSIX message queues\n"
"_CFG_###> \n"
"_CFG_###> # Common compatibility functions. They happen to be needed even when\n"
"_CFG_###> # no compatibility option is explicitly enabled.\n"
"_CFG_###> #\n"
"_CFG_###> options        COMPAT_UTILS\n"
"_CFG_###> \n"
"_CFG_###> #\n"
"_CFG_###> # Security model.\n"
"_CFG_###> #\n"
"_CFG_###> options\\011secmodel_bsd44\\011# Traditional 4.4BSD security model\n"
"_CFG_###> \n"
"_CFG_###> #\n"
"_CFG_###> # Scheduling algorithm\n"
"_CFG_###> #\n"
"_CFG_###> options\\011SCHED_4BSD\n"
"_CFG_###> \n"
"_CFG_###> pseudo-device\\011cpuctl\n"
"_CFG_###> \n"
"_CFG_###> #\n"
"_CFG_###> # Kernel entropy pool and random-number generator pseudodevice.\n"
"_CFG_###> # The pseudodevice might stop being \"std\" when the two are torn\n"
"_CFG_###> # apart some day but the entropy pool itself never will (they are\n"
"_CFG_###> # presently implemented in the same source file)\n"
"_CFG_###> #\n"
"_CFG_###> pseudo-device\\011rnd\n"
"_CFG_### (end include \"conf/std\")\n"
#endif /* INCLUDE_CONFIG_FILE */
;
#endif /* INCLUDE_CONFIG_FILE || INCLUDE_JUST_CONFIG */
#endif /* CONFIG_FILE */
